# This file is generated by objective.metadata
#
# Last update: Mon Sep 24 11:18:48 2012

import sys

import objc

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if sys.byteorder == "little":

    def littleOrBig(a, b):
        return a


else:

    def littleOrBig(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSServerNotificationCenter",
        b"addObserver:selector:name:object:",
        {"arguments": {3: {"type": ":", "sel_of_type": b"v@:@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



"""
Wrappers for framework 'ServerNotification' on macOS 10.6. This framework
contains the class NSServerNotificationCenter which provides distributed
notifications over the Extensible Messaging and Presence Protocol (XMPP).

These wrappers don't include documentation, please check Apple's documention
for information on how to use this framework and PyObjC's documentation
for general tips and tricks regarding the translation between Python
and (Objective-)C frameworks
"""
from pyobjc_setup import setup

VERSION = "6.2.1"

setup(
    name="pyobjc-framework-ServerNotification",
    description="Wrappers for the framework ServerNotification on macOS",
    min_os_level="10.6",
    max_os_level="10.8",
    packages=["ServerNotification"],
    version=VERSION,
    install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
    long_description=__doc__,
)
